==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ASingleParameterList.h <==
// public final class soot.jimple.parser.node.ASingleParameterList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9532bdb55a5ae19c soot_jimple_parser_node_ASingleParameterList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class fb94fdee60938d55 soot_jimple_parser_node_PParameterList

// header file dependencies
// @dep_header soot_jimple_parser_node_PParameterList

#include "soot/jimple/parser/node/PParameterList.h"

#ifndef _JC_soot_jimple_parser_node_ASingleParameterList_H_
#define _JC_soot_jimple_parser_node_ASingleParameterList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PParameter$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_refs	_jc_soot_jimple_parser_node_ASingleParameterList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs	_jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$refs	_jc_soot_jimple_parser_node_ASingleParameterList$refs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$nonrefs	_jc_soot_jimple_parser_node_ASingleParameterList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$object	_jc_soot_jimple_parser_node_ASingleParameterList$object;

typedef const struct _jc_soot_jimple_parser_node_ASingleParameterList$vmethods	_jc_soot_jimple_parser_node_ASingleParameterList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASingleParameterList$vtable	_jc_soot_jimple_parser_node_ASingleParameterList$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASingleParameterList$vtype	_jc_soot_jimple_parser_node_ASingleParameterList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *);
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$_init$d0e73b0cae491480(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_PParameter$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASingleParameterList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *);
extern struct _jc_soot_jimple_parser_node_PParameter$object *_jc_soot_jimple_parser_node_ASingleParameterList$method$getParameter$0f42bc31c66b3b9a(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *);
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$setParameter$d1a720c83c632b4a(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_PParameter$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASingleParameterList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$getParameter$0f42bc31c66b3b9a;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$setParameter$d1a720c83c632b4a;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASingleParameterList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *);
	struct _jc_soot_jimple_parser_node_PParameter$object	*(*getParameter$0f42bc31c66b3b9a)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setParameter$d1a720c83c632b4a)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_PParameter$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ASingleParameterList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PParameterList$vmethods	soot_jimple_parser_node_PParameterList;
	_jc_soot_jimple_parser_node_ASingleParameterList$vmethods	soot_jimple_parser_node_ASingleParameterList;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASingleParameterList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASingleParameterList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_refs {
	struct _jc_soot_jimple_parser_node_PParameter$object	*__5fparameter__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleParameterList$refs {
    _jc_soot_jimple_parser_node_ASingleParameterList$sub_refs	soot_jimple_parser_node_ASingleParameterList;
    _jc_soot_jimple_parser_node_PParameterList$sub_refs	soot_jimple_parser_node_PParameterList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleParameterList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs	soot_jimple_parser_node_PParameterList;
    _jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs	soot_jimple_parser_node_ASingleParameterList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASingleParameterList$object {
	_jc_soot_jimple_parser_node_ASingleParameterList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASingleParameterList$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASingleParameterList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASingleParameterList$vtype _jc_soot_jimple_parser_node_ASingleParameterList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASingleParameterList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASingleParameterList$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASingleParameterList_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ASingleParameterList.h <==
// public final class soot.jimple.parser.node.ASingleParameterList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9532bdb55a5ae19c soot_jimple_parser_node_ASingleParameterList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class fb94fdee60938d55 soot_jimple_parser_node_PParameterList

// header file dependencies
// @dep_header soot_jimple_parser_node_PParameterList

#include "soot/jimple/parser/node/PParameterList.h"

#ifndef _JC_soot_jimple_parser_node_ASingleParameterList_H_
#define _JC_soot_jimple_parser_node_ASingleParameterList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PParameter$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_refs	_jc_soot_jimple_parser_node_ASingleParameterList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs	_jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$refs	_jc_soot_jimple_parser_node_ASingleParameterList$refs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$nonrefs	_jc_soot_jimple_parser_node_ASingleParameterList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleParameterList$object	_jc_soot_jimple_parser_node_ASingleParameterList$object;

typedef const struct _jc_soot_jimple_parser_node_ASingleParameterList$vmethods	_jc_soot_jimple_parser_node_ASingleParameterList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASingleParameterList$vtable	_jc_soot_jimple_parser_node_ASingleParameterList$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASingleParameterList$vtype	_jc_soot_jimple_parser_node_ASingleParameterList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$_init$d0e73b0cae491480(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_PParameter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASingleParameterList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PParameter$object *_jc_soot_jimple_parser_node_ASingleParameterList$method$getParameter$0f42bc31c66b3b9a(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleParameterList$method$setParameter$d1a720c83c632b4a(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_PParameter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASingleParameterList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$getParameter$0f42bc31c66b3b9a;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$setParameter$d1a720c83c632b4a;
extern _jc_method _jc_soot_jimple_parser_node_ASingleParameterList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASingleParameterList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PParameter$object	*(*getParameter$0f42bc31c66b3b9a)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setParameter$d1a720c83c632b4a)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *, struct _jc_soot_jimple_parser_node_PParameter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleParameterList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ASingleParameterList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PParameterList$vmethods	soot_jimple_parser_node_PParameterList;
	_jc_soot_jimple_parser_node_ASingleParameterList$vmethods	soot_jimple_parser_node_ASingleParameterList;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASingleParameterList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASingleParameterList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_refs {
	struct _jc_soot_jimple_parser_node_PParameter$object	*__5fparameter__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleParameterList$refs {
    _jc_soot_jimple_parser_node_ASingleParameterList$sub_refs	soot_jimple_parser_node_ASingleParameterList;
    _jc_soot_jimple_parser_node_PParameterList$sub_refs	soot_jimple_parser_node_PParameterList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleParameterList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs	soot_jimple_parser_node_PParameterList;
    _jc_soot_jimple_parser_node_ASingleParameterList$sub_nonrefs	soot_jimple_parser_node_ASingleParameterList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASingleParameterList$object {
	_jc_soot_jimple_parser_node_ASingleParameterList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASingleParameterList$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASingleParameterList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASingleParameterList$vtype _jc_soot_jimple_parser_node_ASingleParameterList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASingleParameterList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASingleParameterList$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASingleParameterList_H_ */
